"""Tests for grid row-level access API."""

from unittest.mock import MagicMock

from easypptx import Presentation
from easypptx.grid import Grid, GridRowProxy


def test_grid_row_access():
    """Test the row-level access API for Grid."""
    # Create a mock parent
    parent = MagicMock()
    parent.add_text = MagicMock(return_value="text_shape")
    parent.add_image = MagicMock(return_value="image_shape")

    # Create a grid
    grid = Grid(parent=parent, rows=2, cols=2)

    # Test accessing a row using grid[row]
    row_proxy = grid[0]
    assert isinstance(row_proxy, GridRowProxy)
    assert row_proxy.row == 0
    assert row_proxy.current_col == 0

    # Test accessing a cell using row_proxy[col]
    cell_proxy = row_proxy[1]
    assert cell_proxy.row == 0
    assert cell_proxy.col == 1

    # Test adding content to a row (should go to the next available column)
    result1 = row_proxy.add_text("Text 1")
    assert result1 == "text_shape"
    assert row_proxy.current_col == 1  # Column index incremented

    # Add another item to the row
    result2 = row_proxy.add_text("Text 2")
    assert result2 == "text_shape"
    assert row_proxy.current_col == 2  # Column index incremented again

    # Test row reset
    row_proxy.reset()
    assert row_proxy.current_col == 0

    # Test row overflow
    row_proxy.add_text("Text 3")  # col 0
    row_proxy.add_text("Text 4")  # col 1
    # This should raise an IndexError as we're out of columns
    try:
        row_proxy.add_text("Text 5")  # col 2 (overflow)
        assert False, "Expected IndexError when exceeding available columns"
    except IndexError:
        pass


def test_grid_textbox_alias():
    """Test the alias add_textbox for add_text in GridRowProxy."""
    # Create a mock parent
    parent = MagicMock()
    parent.add_text = MagicMock(return_value="text_shape")

    # Create a grid
    grid = Grid(parent=parent, rows=2, cols=2)

    # Get a row proxy
    row_proxy = grid[0]

    # Test add_textbox
    result = row_proxy.add_textbox("Text", font_size=18)
    assert result == "text_shape"

    # Verify parent.add_text was called with the right arguments
    parent.add_text.assert_called_once()
    call_kwargs = parent.add_text.call_args[1]
    assert call_kwargs["text"] == "Text"
    assert call_kwargs["font_size"] == 18


def test_add_autogrid_slide_empty():
    """Test the add_autogrid_slide method with an empty grid."""
    pres = Presentation()
    
    # Test with empty grid
    slide, grid = pres.add_autogrid_slide(
        content_funcs=None,
        rows=3,
        cols=2,
        title="Test Title"
    )
    
    # Verify grid dimensions
    assert grid.rows == 3
    assert grid.cols == 2
    
    # Test adding content to the grid
    grid[0].add_textbox("Row 0, Col 0")
    grid[0].add_textbox("Row 0, Col 1")
    
    # The row's current column should be 2 now
    assert grid[0].current_col == 2
    
    # Reset the row counter
    grid[0].reset()
    assert grid[0].current_col == 0